@@ -41,8 +41,6 @@
 
 #define KJOBWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KJOBWIDGETS_NO_DEPRECATED) && !defined(KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KJOBWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KJOBWIDGETS_NO_DEPRECATED
-#  define KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KJOBWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KJOBWIDGETS_DEPRECATED
-#  define KJOBWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KJOBWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KJOBWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KJOBWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
